package com.databasesample;

import android.app.Activity;
import android.content.ContentValues;
import android.content.Context;
import android.database.Cursor;
import android.database.SQLException;
import android.database.sqlite.SQLiteDatabase;
import android.database.sqlite.SQLiteOpenHelper;
import android.os.Bundle;
import android.view.KeyEvent;
import android.widget.TextView;

public class DatabaseSample extends Activity {
    /** Called when the activity is first created. */
    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.main);
        
        Database db = new Database();
        db.open(this);
        db.insertItem("water");
        db.insertItem("cats");
        db.insertItem("dogs");
        db.insertItem("cars");
        db.close();
        
        db.open(this);
        Cursor items = db.fetchAllItems();
        StringBuffer displayItems = new StringBuffer();
        while (items.getPosition() < items.getCount()) {
			String item = items.getString(items.getColumnIndexOrThrow(Database.SAMPLE_ITEM));
			displayItems.append( item + " "  );
			items.moveToNext();
        }
        db.close();
        
        final TextView text = (TextView) findViewById(R.id.text);
        text.setText( displayItems.toString() );
    }
    
	@Override
	public boolean onKeyDown(int keyCode, KeyEvent msg) {
		if (keyCode == KeyEvent.KEYCODE_CAMERA) {
			return true;
        } else if (keyCode == KeyEvent.KEYCODE_CALL) {
        	return true;
		} else if (keyCode == KeyEvent.KEYCODE_BACK) {
			finish();
			return true;
		}

		return false;
	}
	
	private static class Database {
		
		public static final String KEY_ROWID = "_id";
		public static final String SAMPLE_ITEM = "item";
		
		private static final String DATABASE_NAME = "data";
		private static final String DATABASE_TABLE = "sampledatabase";
		private static final int DATABASE_VERSION = 1;		
		
		private DatabaseHelper dbHelper;
		private SQLiteDatabase db;		
		
		private static final String DATABASE_CREATE =
			"create table " + DATABASE_TABLE + " ( _id integer primary key autoincrement, "
			+ SAMPLE_ITEM + " text not null );";	
		
		private static class DatabaseHelper extends SQLiteOpenHelper {
			DatabaseHelper(Context context) {
				super(context, DATABASE_NAME, null, DATABASE_VERSION);
			}
			
			@Override
			public void onCreate(SQLiteDatabase db) {
				db.execSQL(DATABASE_CREATE);
			}
			
			@Override
			public void onUpgrade(SQLiteDatabase db, int oldVersion, int newVersion) {
				db.execSQL("DROP TABLE IF EXISTS " + DATABASE_TABLE );
				onCreate(db);
			}
		}
		
		public Database() {
		}
		
		public Database open(final Context ctx) throws SQLException {
			dbHelper = new DatabaseHelper(ctx);
			db = dbHelper.getWritableDatabase();
			return this;
		}
		
		public void close() {
			dbHelper.close();
		}
		
		/**
		* Create a new item. If the new item is
		* successfully created return the new rowId for that item, otherwise return
		* a -1 to indicate failure.
		* 
		* @return rowId or -1 if failed
		*/
		public long insertItem( final String item ) {
			final ContentValues initialValues = new ContentValues();
			initialValues.put( SAMPLE_ITEM, item );
			return db.insert( DATABASE_TABLE, null, initialValues );
		}
		
		/**
		* Return a Cursor over the list of all items in the database
		* 
		* @return Cursor over all items
		*/
		public Cursor fetchAllItems() {		
			Cursor mCursor = db.query(
				DATABASE_TABLE, 
				new String[]  {
					KEY_ROWID,
					SAMPLE_ITEM,
				}, 
				null, null, null, null, null);
			
			if (mCursor != null) {
				mCursor.moveToNext();
			}		
			
			
			
			return mCursor;
		}
	}
}